"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const fs = require("fs");
const yaml = require("js-yaml");
function loadConfig(logger, filename) {
    // We have the file, so attempt to load it into memory. This will either be
    // a YAML or a JSON file.
    let extension = path.extname(filename);
    logger.debug("publicationFile", filename + ", ext", extension);
    switch (extension) {
        case ".yaml":
        case ".yml":
            return loadYaml(filename);
        case ".json":
            return loadJson(filename);
    }
    // If we fell through to this point, we don't know how to parse that file
    // type.
    logger.error(`Cannot parse ${extension} file types`);
    return undefined;
}
exports.loadConfig = loadConfig;
function loadYaml(filename) {
    let text = loadText(filename);
    let data = yaml.safeLoad(text);
    return data;
}
function loadJson(filename) {
    return JSON.parse(loadText(filename));
}
function loadText(filename) {
    return fs.readFileSync(filename).toString();
}
//# sourceMappingURL=configs.js.map